/* 
 * File:   SwitchFunctions.h
 * Author: rmcnamee
 *
 * Created on January 30, 2018, 8:25 AM
 */

#ifndef SWITCHFUNCTIONS_H
#define SWITCHFUNCTIONS_H

#ifdef __cplusplus
extern "C"
{
#endif

void SetupSwitch(void);
bool ReadSwitchPress(void);
void LoadBlankImageOnSwitch(void);
void LoadWebcamImageOnSwitch(char * inputImage);

// Switch commands per the data sheet
typedef enum
{
    SWITCH_WINDOW_COLUMN            = 0x15,
    SWITCH_WINDOW_ROW               = 0x75,
    SWITCH_CONTRAST_COLOR_A         = 0x81,
    SWITCH_CONTRAST_COLOR_B         = 0x82,
    SWITCH_CONTRAST_COLOR_C         = 0x83,
    SWITCH_MASTER_CURRENT_CONTROL   = 0x87,
    SWITCH_COLOR_A_PRECHARGE_SPEED  = 0x8A,
    SWITCH_COLOR_B_PRECHARGE_SPEED  = 0x8B,
    SWITCH_COLOR_C_PRECHARGE_SPEED  = 0x8C,    
    SWITCH_COLOR_DEPTH              = 0xA0,
    SWITCH_DISPLAY_START_LINE       = 0xA1,
    SWITCH_DISPLAY_OFFSET           = 0xA2,
    SWITCH_DISPLAY_NORMAL           = 0xA4,
    SWITCH_MULTIPLEX_RATIO          = 0xA8,
    SWITCH_COLOR_DIM_MODE           = 0xAB,
    SWITCH_MASTER_CONFIGURATION     = 0xAD,
    SWITCH_POWER_SAVE_MODE          = 0xB0,
    SWITCH_PHASE_1_2_PERIOD_ADJUST  = 0xB1,
    SWITCH_DISPLAY_CLOCK_DIVIDER    = 0xB3,
    SWITCH_ENABLE_LINEAR_GRAYSCALE  = 0xB9,
    SWITCH_PRECHARGE_LEVEL          = 0xBB,
    SWITCH_SET_VCOMH                = 0xBE,
    SWITCH_DISPLAY_OFF              = 0xAE,
    SWITCH_DISPLAY_ON               = 0xAF
}switchCommandsEnum;

typedef enum
{
	SWITCH_TYPE_FRAMELESS = 0x00,
	SWITCH_TYPE_STANDARD
}switchTypeEnum;

#define STANDARD_CONTRAST_A_DEFAULT             0x15
#define STANDARD_CONTRAST_B_DEFAULT             0x1A
#define STANDARD_CONTRAST_C_DEFAULT             0x17
#define STANDARD_MASTER_CURRENT_DEFAULT         0x0F
#define STANDARD_COLOR_DEPTH_DEFAULT            0x70
#define STANDARD_DISPLAY_START_LINE_DEFAULT     0x00
#define STANDARD_DISPLAY_OFFSET_DEFAULT         0x10
#define STANDARD_MULTIPLEX_RATIO_DEFAULT        0x2F
#define STANDARD_DIM_MODE_DEFAULT_1             0x00
#define STANDARD_DIM_MODE_DEFAULT_2             0x12
#define STANDARD_DIM_MODE_DEFAULT_3             0x0C
#define STANDARD_DIM_MODE_DEFAULT_4             0x14
#define STANDARD_DIM_MODE_DEFAULT_5             0x12
#define STANDARD_MASTER_CONFIGURATION_DEFAULT   0x8E
#define STANDARD_POWER_SAVE_MODE_DEFAULT        0x0B
#define STANDARD_PHASE_PERIOD_DEFAULT           0x44
#define STANDARD_DISPLAY_CLOCK_DIVIDER_DEFAULT  0xA0
#define STANDARD_PRECHARGE_LEVEL_DEFAULT        0xB9
#define STANDARD_VCOMH_DEFAULT                  0x3E
#define STANDARD_WINDOW_COLUMN_DEFAULT_1        0x10
#define STANDARD_WINDOW_COLUMN_DEFAULT_2        0x4F
#define STANDARD_WINDOW_ROW_DEFAULT_1           0x00
#define STANDARD_WINDOW_ROW_DEFAULT_2           0x2F

#define FRAMELESS_CONTRAST_A_DEFAULT            0x1C
#define FRAMELESS_CONTRAST_B_DEFAULT            0x2E
#define FRAMELESS_CONTRAST_C_DEFAULT            0x2C
#define FRAMELESS_COLOR_A_PRECHARGE_DEFAULT     0x4F
#define FRAMELESS_COLOR_B_PRECHARGE_DEFAULT     0x74
#define FRAMELESS_COLOR_C_PRECHARGE_DEFAULT     0x88
#define FRAMELESS_MASTER_CURRENT_DEFAULT        0x0F
#define FRAMELESS_COLOR_DEPTH_DEFAULT           0x68
#define FRAMELESS_DISPLAY_START_LINE_DEFAULT    0x00
#define FRAMELESS_DISPLAY_OFFSET_DEFAULT        0x00
#define FRAMELESS_MULTIPLEX_RATIO_DEFAULT       0x3F
#define FRAMELESS_DIM_MODE_DEFAULT_1            0x00
#define FRAMELESS_DIM_MODE_DEFAULT_2            0x0E
#define FRAMELESS_DIM_MODE_DEFAULT_3            0x17
#define FRAMELESS_DIM_MODE_DEFAULT_4            0x16
#define FRAMELESS_DIM_MODE_DEFAULT_5            0x12
#define FRAMELESS_MASTER_CONFIGURATION_DEFAULT  0x8E
#define FRAMELESS_POWER_SAVE_MODE_DEFAULT       0x0B
#define FRAMELESS_PHASE_PERIOD_DEFAULT          0x17
#define FRAMELESS_DISPLAY_CLOCK_DIVIDER_DEFAULT 0xF0
#define FRAMELESS_PRECHARGE_LEVEL_DEFAULT       0x1D
#define FRAMELESS_VCOMH_DEFAULT                 0x20
#define FRAMELESS_WINDOW_COLUMN_DEFAULT_1       0x00
#define FRAMELESS_WINDOW_COLUMN_DEFAULT_2       0x5F
#define FRAMELESS_WINDOW_ROW_DEFAULT_1          0x00
#define FRAMELESS_WINDOW_ROW_DEFAULT_2          0x3F


#ifdef __cplusplus
}
#endif

#endif /* SWITCHFUNCTIONS_H */

